@@ -1,53 +1,293 @@
-from typing import Any
+from typing import Any, Self
 
 from typing_extensions import override
 
-from .static import (
+from .static.enum import (
     AccessType,
     AttachType,
     ChatType,
-    ElementType,
     FormattingType,
     MessageStatus,
     MessageType,
 )
 
+# TODO: все это нужно переделать на pydantic модели.
+# Я просто придерживаюсь текущего стиля.
+# - 6RUN0
+# Хз, а в чем аргументация, так контроля больше и пайдентик модели явного преимущества не дают.
+# - ink-developer
 
-class Names:
+
+class Presence:
+    def __init__(self, seen: int | None) -> None:
+        """
+        Присутствие пользователя.
+
+        {
+            "seen": {{ unix timestamp }}
+        },
+        """
+        # TODO надо сделать пребразование в datetime с учетом таймзоны
+        self.seen = seen
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(seen=data.get("seen"))
+
+    @override
+    def __repr__(self) -> str:
+        return f"Presence(seen={self.seen!r})"
+
+    @override
+    def __str__(self) -> str:
+        return f"{self.seen}"
+
+
+class Name:
     def __init__(
-        self, name: str, first_name: str, last_name: str | None, type: str
+        self,
+        name: str | None,
+        first_name: None,
+        last_name: str | None,
+        type: str | None,
     ) -> None:
+        """
+        Структура имени пользователя.
+
+        Структура может поменяться, ничего не гарантируется.
+        На данный момент она такая:
+        {
+            "name": "Василий",
+            "firstName": "Пупкин",
+            "lastName": "Чеевич",
+            "type": "ONEME"
+        }
+        """
         self.name = name
         self.first_name = first_name
         self.last_name = last_name
         self.type = type
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "Names":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
-            name=data["name"],
-            first_name=data["firstName"],
+            name=data.get("name"),
+            first_name=data.get("firstName"),
             last_name=data.get("lastName"),
-            type=data["type"],
+            type=data.get("type"),
         )
 
     @override
     def __repr__(self) -> str:
-        return f"Names(name={self.name!r}, first_name={self.first_name!r}, last_name={self.last_name!r}, type={self.type!r})"
+        return f"Name(name={self.name!r}, first_name={self.first_name!r}, last_name={self.last_name!r}, type={self.type!r})"
 
     @override
     def __str__(self) -> str:
-        return self.name
+        return self.name or ""
+
+
+class Names(Name):
+    def __init__(
+        self,
+        name: str | None,
+        first_name: None,
+        last_name: str | None,
+        type: str | None,
+    ) -> None:
+        """
+        Синоним для класса Name.
+        """
+        super().__init__(
+            name=name, first_name=first_name, last_name=last_name, type=type
+        )
+
+
+class Contact:
+    def __init__(
+        self,
+        id: int | None,
+        account_status: int | None,
+        base_raw_url: str | None,
+        base_url: str | None,
+        names: list[Name] | None,
+        options: list[str] | None,
+        photo_id: int | None,
+        update_time: int | None,
+    ) -> None:
+        """
+        Контакт.
+
+        Сруктура:
+        {
+            "accountStatus": 0,
+            "baseUrl": "https://i.oneme.ru/i?r=...",
+            "names": [
+                Name{},
+            ],
+            "options": [
+                "TT",
+                "ONEME"
+            ],
+            "photoId": {{ file id }},
+            "updateTime": 0,
+            "id": {{ user id }},
+            "baseRawUrl": "https://i.oneme.ru/i?r=..."
+        }
+        """
+        self.id = id
+        self.account_status = account_status
+        self.base_raw_url = base_raw_url
+        self.base_url = base_url
+        self.names = names
+        self.options = options or []
+        self.photo_id = photo_id
+        # TODO надо сделать пребразование в datetime с учетом таймзоны
+        self.update_time = update_time
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(
+            account_status=data.get("accountStatus"),
+            update_time=data.get("updateTime"),
+            id=data.get("id"),
+            names=[Name.from_dict(n) for n in data.get("names", [])],
+            options=data.get("options"),
+            base_url=data.get("baseUrl"),
+            base_raw_url=data.get("baseRawUrl"),
+            photo_id=data.get("photoId"),
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return f"Contact(id={self.id!r}, names={self.names!r}, status={self.account_status!r})"
+
+    @override
+    def __str__(self) -> str:
+        return (
+            f"Contact {self.id}: {', '.join(str(n) for n in self.names or [])}"
+        )
+
+
+class Member:
+    def __init__(
+        self,
+        contact: Contact,
+        presence: Presence,
+        read_mark: int | None,
+    ) -> None:
+        """
+        Участник чата.
+
+        Структура:
+        {
+            "presence": Presence{}
+            "readMark": {{ timestamp with milliseconds }},
+            "contact": Contact{}
+        },
+        """
+        self.presence = presence
+        # TODO надо сделать пребразование в datetime с учетом таймзоны
+        self.read_mark = read_mark
+        self.contact = contact
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        presence_value = data.get("presence")
+        if isinstance(presence_value, dict):
+            presence = Presence.from_dict(presence_value)
+        else:
+            presence = Presence.from_dict({})
+        contact_value = data.get("contact")
+        if isinstance(contact_value, dict):
+            contact = Contact.from_dict(contact_value)
+        else:
+            contact = Contact.from_dict({})
+        return cls(
+            contact=contact,
+            presence=presence,
+            read_mark=data.get("readMark"),
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return f"Member(presence={self.presence!r}, read_mark={self.read_mark!r}, contact={self.contact!r})"
+
+    @override
+    def __str__(self) -> str:
+        return f"Member {self.contact.id}: {', '.join(str(n) for n in self.contact.names or [])}"
+
+
+class StickerAttach:
+    def __init__(
+        self,
+        author_type: str,
+        lottie_url: str,
+        url: str,
+        sticker_id: int,
+        tags: list[str] | None,
+        width: int,
+        set_id: int,
+        time: int,
+        sticker_type: str,
+        audio: bool,
+        height: int,
+        type: AttachType,
+    ):
+        self.author_type = author_type
+        self.lottie_url = lottie_url
+        self.url = url
+        self.sticker_id = sticker_id
+        self.tags = tags
+        self.width = width
+        self.set_id = set_id
+        self.time = time
+        self.sticker_type = sticker_type
+        self.audio = audio
+        self.height = height
+        self.type = type
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> Self:
+        return cls(
+            author_type=data["authorType"],
+            lottie_url=data["lottieUrl"],
+            url=data["url"],
+            sticker_id=data["stickerId"],
+            tags=data.get("tags"),
+            width=data["width"],
+            set_id=data["setId"],
+            time=data["time"],
+            sticker_type=data["stickerType"],
+            audio=data["audio"],
+            height=data["height"],
+            type=AttachType(data["_type"]),
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return (
+            f"StickerAttach(author_type={self.author_type!r}, lottie_url={self.lottie_url!r}, "
+            f"url={self.url!r}, sticker_id={self.sticker_id!r}, tags={self.tags!r}, "
+            f"width={self.width!r}, set_id={self.set_id!r}, time={self.time!r}, "
+            f"sticker_type={self.sticker_type!r}, audio={self.audio!r}, height={self.height!r}, "
+            f"type={self.type!r})"
+        )
+
+    @override
+    def __str__(self) -> str:
+        return f"StickerAttach: {self.sticker_id}"
 
 
 class ControlAttach:
-    def __init__(self, type: AttachType, event: str, **kwargs: dict[str, Any]) -> None:
+    def __init__(
+        self, type: AttachType, event: str, **kwargs: dict[str, Any]
+    ) -> None:
         self.type = type
         self.event = event
         self.extra = kwargs
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "ControlAttach":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         data = dict(data)
         attach_type = AttachType(data.pop("_type"))
         event = data.pop("event")
@@ -86,7 +326,7 @@ class PhotoAttach:
         self.type = type
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "PhotoAttach":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             base_url=data["baseUrl"],
             height=data["height"],
@@ -134,7 +374,7 @@ class VideoAttach:
         self.video_type = video_type
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "VideoAttach":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             height=data["height"],
             width=data["width"],
@@ -173,7 +413,7 @@ class FileAttach:
         self.type = type
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "FileAttach":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             file_id=data["fileId"],
             name=data["name"],
@@ -204,7 +444,7 @@ class FileRequest:
         self.url = url
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "FileRequest":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             unsafe=data["unsafe"],
             url=data["url"],
@@ -223,7 +463,7 @@ class VideoRequest:
         self.url = url
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "VideoRequest":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         # listdata = list(data.values()) # Костыль ✅
         url = [v for k, v in data.items() if k not in ("EXTERNAL", "cache")][
             0
@@ -253,7 +493,7 @@ class Me:
         self.names = names
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "Me":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             id=data["id"],
             account_status=data["accountStatus"],
@@ -281,14 +521,14 @@ class Element:
         self.from_ = from_
 
     @classmethod
-    def from_dict(cls, data: dict[Any, Any]) -> "Element":
-        return cls(type=data["type"], length=data["length"], from_=data.get("from"))
+    def from_dict(cls, data: dict[Any, Any]) -> Self:
+        return cls(
+            type=data["type"], length=data["length"], from_=data.get("from")
+        )
 
     @override
     def __repr__(self) -> str:
-        return (
-            f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
-        )
+        return f"Element(type={self.type!r}, length={self.length!r}, from_={self.from_!r})"
 
     @override
     def __str__(self) -> str:
@@ -302,7 +542,7 @@ class MessageLink:
         self.type = type
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "MessageLink":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             chat_id=data["chatId"],
             message=Message.from_dict(data["message"]),
@@ -324,7 +564,7 @@ class ReactionCounter:
         self.reaction = reaction
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "ReactionCounter":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(count=data["count"], reaction=data["reaction"])
 
     @override
@@ -348,10 +588,12 @@ class ReactionInfo:
         self.your_reaction = your_reaction
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "ReactionInfo":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             total_count=data.get("totalCount", 0),
-            counters=[ReactionCounter.from_dict(c) for c in data.get("counters", [])],
+            counters=[
+                ReactionCounter.from_dict(c) for c in data.get("counters", [])
+            ],
             your_reaction=data.get("yourReaction"),
         )
 
@@ -368,9 +610,18 @@ class Message:
         time: int,
         link: MessageLink | None,
         text: str,
-        status: MessageStatus | str | None,
+        status: MessageStatus | None,
         type: MessageType | str,
-        attaches: list[PhotoAttach | VideoAttach | FileAttach | ControlAttach] | None,
+        attaches: (
+            list[
+                PhotoAttach
+                | VideoAttach
+                | FileAttach
+                | ControlAttach
+                | StickerAttach
+            ]
+            | None
+        ),
     ) -> None:
         self.chat_id = chat_id
         self.sender = sender
@@ -386,9 +637,15 @@ class Message:
         self.reactionInfo = reaction_info
 
     @classmethod
-    def from_dict(cls, data: dict[Any, Any]) -> "Message":
+    def from_dict(cls, data: dict[Any, Any]) -> Self:
         message = data["message"] if data.get("message") else data
-        attaches = []
+        attaches: list[
+            PhotoAttach
+            | VideoAttach
+            | FileAttach
+            | ControlAttach
+            | StickerAttach
+        ] = []
         for a in message.get("attaches", []):
             if a["_type"] == AttachType.PHOTO:
                 attaches.append(PhotoAttach.from_dict(a))
@@ -398,10 +655,24 @@ class Message:
                 attaches.append(FileAttach.from_dict(a))
             elif a["_type"] == AttachType.CONTROL:
                 attaches.append(ControlAttach.from_dict(a))
+            elif a["_type"] == AttachType.STICKER:
+                attaches.append(StickerAttach.from_dict(a))
+        link_value = message.get("link")
+        if isinstance(link_value, dict):
+            link = MessageLink.from_dict(link_value)
+        else:
+            link = None
+        reaction_info_value = message.get("reactionInfo")
+        if isinstance(reaction_info_value, dict):
+            reaction_info = ReactionInfo.from_dict(reaction_info_value)
+        else:
+            reaction_info = None
         return cls(
             chat_id=data.get("chatId"),
             sender=message.get("sender"),
-            elements=[Element.from_dict(e) for e in message.get("elements", [])],
+            elements=[
+                Element.from_dict(e) for e in message.get("elements", [])
+            ],
             options=message.get("options"),
             id=message["id"],
             time=message["time"],
@@ -409,12 +680,8 @@ class Message:
             type=message["type"],
             attaches=attaches,
             status=message.get("status"),
-            link=MessageLink.from_dict(message.get("link"))
-            if message.get("link")
-            else None,
-            reaction_info=ReactionInfo.from_dict(message.get("reactionInfo"))
-            if message.get("reactionInfo")
-            else None,
+            link=link,
+            reaction_info=reaction_info,
         )
 
     @override
@@ -468,16 +735,18 @@ class Dialog:
         self.participants = participants
 
     @classmethod
-    def from_dict(cls, data: dict[Any, Any]) -> "Dialog":
+    def from_dict(cls, data: dict[Any, Any]) -> Self:
         return cls(
             cid=data.get("cid"),
             owner=data["owner"],
             has_bots=data.get("hasBots"),
             join_time=data["joinTime"],
             created=data["created"],
-            last_message=Message.from_dict(data["lastMessage"])
-            if data.get("lastMessage")
-            else None,
+            last_message=(
+                Message.from_dict(data["lastMessage"])
+                if data.get("lastMessage")
+                else None
+            ),
             type=ChatType(data["type"]),
             last_fire_delayed_error_time=data["lastFireDelayedErrorTime"],
             last_delayed_update_time=data["lastDelayedUpdateTime"],
@@ -559,15 +828,19 @@ class Chat:
         self.cid = cid
 
     @classmethod
-    def from_dict(cls, data: dict[Any, Any]) -> "Chat":
+    def from_dict(cls, data: dict[Any, Any]) -> Self:
         raw_admins = data.get("adminParticipants", {}) or {}
         admin_participants: dict[int, dict[Any, Any]] = {
             int(k): v for k, v in raw_admins.items()
         }
         raw_participants = data.get("participants", {}) or {}
-        participants: dict[int, int] = {int(k): v for k, v in raw_participants.items()}
+        participants: dict[int, int] = {
+            int(k): v for k, v in raw_participants.items()
+        }
         last_msg = (
-            Message.from_dict(data["lastMessage"]) if data.get("lastMessage") else None
+            Message.from_dict(data["lastMessage"])
+            if data.get("lastMessage")
+            else None
         )
         return cls(
             participants_count=data.get("participantsCount", 0),
@@ -579,7 +852,9 @@ class Chat:
             description=data.get("description"),
             chat_type=ChatType(data.get("type", ChatType.CHAT.value)),
             title=data.get("title"),
-            last_fire_delayed_error_time=data.get("lastFireDelayedErrorTime", 0),
+            last_fire_delayed_error_time=data.get(
+                "lastFireDelayedErrorTime", 0
+            ),
             last_delayed_update_time=data.get("lastDelayedUpdateTime", 0),
             options=data.get("options", {}),
             modified=data.get("modified", 0),
@@ -601,7 +876,9 @@ class Chat:
 
     @override
     def __repr__(self) -> str:
-        return f"Chat(id={self.id!r}, title={self.title!r}, type={self.type!r})"
+        return (
+            f"Chat(id={self.id!r}, title={self.title!r}, type={self.type!r})"
+        )
 
     @override
     def __str__(self) -> str:
@@ -650,7 +927,7 @@ class User:
         self.menu_button = menu_button
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "User":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             account_status=data["accountStatus"],
             update_time=data["updateTime"],
@@ -692,7 +969,7 @@ class Attach:  # УБРАТЬ ГАДА!!! или нет...
         self.token = token
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "Attach":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             _type=AttachType(data["type"]),
             video_id=data.get("videoId"),
@@ -729,7 +1006,7 @@ class Session:
         self.current = current if current is not None else False
 
     @classmethod
-    def from_dict(cls, data: dict[str, Any]) -> "Session":
+    def from_dict(cls, data: dict[str, Any]) -> Self:
         return cls(
             client=data["client"],
             info=data["info"],
